import typing
import collections.abc
from . import complete_calltip
from . import complete_import
from . import complete_namespace
from . import intellisense

GenericType1 = typing.TypeVar("GenericType1")
GenericType2 = typing.TypeVar("GenericType2")
