"""
This module provides access to selection.

"""

import typing
import collections.abc

GenericType1 = typing.TypeVar("GenericType1")
GenericType2 = typing.TypeVar("GenericType2")

def load_id(id):
    """Set the selection ID.

    :param id: Number (32-bit uint).
    """

    ...
